==> iamport_flutter-0.10.0-dev.2.tar.gz: lib/model/url_data.dart <==
class UrlData {
  static const String redirectUrl =
      'http://detectchangingwebview/iamport/f'; // f는 flutter의 f
  static const String ANDROID_MARKET_PREFIX = 'market://details?id=';
  static const String IOS_MARKET_PREFIX = 'https://apps.apple.com/app/';

  static const String ISP = 'ispmobile';
  static const String PACKAGE_ISP = 'kvp.jjy.MispAndroid320';

  static const String BANKPAY = 'kftc-bankpay';
  static const String PACKAGE_BANKPAY = 'com.kftc.bankpay.android';

  static const String KB_BANKPAY = 'kb-bankpay';
  static const String PACKAGE_KB_BANKPAY = 'com.kbstar.liivbank';

  static const String NH_BANKPAY = 'nhb-bankpay';
  static const String PACKAGE_NH_BANKPAY = 'com.nh.cashcardapp';

  static const String MG_BANKPAY = 'mg-bankpay';
  static const String PACKAGE_MG_BANKPAY = 'kr.co.kfcc.mobilebank';

  static const String KN_BANKPAY = 'kn-bankpay';
  static const String PACKAGE_KN_BANKPAY = 'com.knb.psb';

  static const String KAKAOPAY = 'kakaotalk';
  static const String PACKAGE_KAKAOPAY = 'com.kakao.talk';

  static const String SMILEPAY = 'smilepayapp';
  static const String PACKAGE_SMILEPAY = 'com.mysmilepay.app';
  static const String SMILEPAY_BASE_URL = "https://www.mysmilepay.com/";

  static const String CHAIPAY = 'chaipayment';
  static const String PACKAGE_CHAIPAY = 'finance.chai.app';

  static const String PAYCO = 'payco';
  static const String PACKAGE_PAYCO = 'com.nhnent.payapp';

  static const String HYUNDAICARD = 'hdcardappcardansimclick';
  static const String PACKAGE_HYUNDAICARD = 'com.hyundaicard.appcard';

  static const String TOSS = 'supertoss';
  static const String PACKAGE_TOSS = 'viva.republica.toss';

  static const String SHINHANCARD = 'shinhan-sr-ansimclick';
  static const String PACKAGE_SHINHANCARD = 'com.shcard.smartpay';

  static const String HANACARD = 'cloudpay';
  static const String PACKAGE_HANACARD = 'com.hanaskard.paycla';

  static const String SAMSUNGCARD = 'mpocket.online.ansimclick';
  static const String PACKAGE_SAMSUNGCARD = 'kr.co.samsungcard.mpocket';

  static const String KBCARD = 'kb-acp';
  static const String PACKAGE_KBCARD = 'com.kbcard.cxh.appcard';

  static const String NHCARD = 'nhallonepayansimclick';
  static const String PACKAGE_NHCARD = 'nh.smart.nhallonepay';

  static const String CITICARD = 'citimobileapp';
  static const String PACKAGE_CITICARD = 'kr.co.citibank.citimobile';

  static const String LOTTECARD = 'lotteappcard';
  static const String PACKAGE_LOTTECARD = 'com.lcacApp';

  static const String LPAY = 'lpayapp';
  static const String PACKAGE_LPAY = 'com.lotte.lpay';

  static const String SSGPAY = 'shinsegaeeasypayment';
  static const String PACKAGE_SSGPAY =
      'com.ssg.serviceapp.android.egiftcertificate';

  static const String KPAY = 'kpay';
  static const String PACKAGE_KPAY = 'com.inicis.kpay';

  static const String PAYNOW = 'lguthepay-xpay';
  static const String PACKAGE_PAYNOW = 'com.lguplus.paynow';

  static const String WOORIWONCARD = 'com.wooricard.smartapp';
  static const String PACKAGE_WOORIWONCARD = 'com.wooricard.smartapp';

  static const String LPOINT = 'lmslpay';
  static const String PACKAGE_LPOINT = 'com.lottemembers.android';
}

==> iamport_flutter-0.10.12.tar.gz: lib/model/url_data.dart <==
class UrlData {
  static const String redirectUrl =
      'http://detectchangingwebview/iamport/f'; // f는 flutter의 f
  static const String ANDROID_MARKET_PREFIX = 'market://details?id=';
  static const String IOS_MARKET_PREFIX = 'https://apps.apple.com/app/';

  static const String ISP = 'ispmobile';
  static const String PACKAGE_ISP = 'kvp.jjy.MispAndroid320';

  static const String BANKPAY = 'kftc-bankpay';
  static const String PACKAGE_BANKPAY = 'com.kftc.bankpay.android';

  static const String KB_BANKPAY = 'kb-bankpay';
  static const String PACKAGE_KB_BANKPAY = 'com.kbstar.liivbank';

  static const String NH_BANKPAY = 'nhb-bankpay';
  static const String PACKAGE_NH_BANKPAY = 'com.nh.cashcardapp';

  static const String MG_BANKPAY = 'mg-bankpay';
  static const String PACKAGE_MG_BANKPAY = 'kr.co.kfcc.mobilebank';

  static const String KN_BANKPAY = 'kn-bankpay';
  static const String PACKAGE_KN_BANKPAY = 'com.knb.psb';

  static const String KAKAOPAY = 'kakaotalk';
  static const String PACKAGE_KAKAOPAY = 'com.kakao.talk';

  static const String SMILEPAY = 'smilepayapp';
  static const String PACKAGE_SMILEPAY = 'com.mysmilepay.app';
  static const String SMILEPAY_BASE_URL = "https://www.mysmilepay.com/";

  static const String CHAIPAY = 'chaipayment';
  static const String PACKAGE_CHAIPAY = 'finance.chai.app';

  static const String PAYCO = 'payco';
  static const String PACKAGE_PAYCO = 'com.nhnent.payapp';

  static const String HYUNDAICARD = 'hdcardappcardansimclick';
  static const String PACKAGE_HYUNDAICARD = 'com.hyundaicard.appcard';

  static const String TOSS = 'supertoss';
  static const String PACKAGE_TOSS = 'viva.republica.toss';

  static const String SHINHANCARD = 'shinhan-sr-ansimclick';
  static const String PACKAGE_SHINHANCARD = 'com.shcard.smartpay';

  static const String HANACARD = 'cloudpay';
  static const String PACKAGE_HANACARD = 'com.hanaskcard.paycla';

  static const String SAMSUNGCARD = 'mpocket.online.ansimclick';
  static const String PACKAGE_SAMSUNGCARD = 'kr.co.samsungcard.mpocket';

  static const String KBCARD = 'kb-acp';
  static const String PACKAGE_KBCARD = 'com.kbcard.cxh.appcard';

  static const String NHCARD = 'nhallonepayansimclick';
  static const String PACKAGE_NHCARD = 'nh.smart.nhallonepay';

  static const String CITICARD = 'citimobileapp';
  static const String PACKAGE_CITICARD = 'kr.co.citibank.citimobile';

  static const String LOTTECARD = 'lotteappcard';
  static const String PACKAGE_LOTTECARD = 'com.lcacApp';

  static const String LPAY = 'lpayapp';
  static const String PACKAGE_LPAY = 'com.lotte.lpay';

  static const String SSGPAY = 'shinsegaeeasypayment';
  static const String PACKAGE_SSGPAY =
      'com.ssg.serviceapp.android.egiftcertificate';

  static const String KPAY = 'kpay';
  static const String PACKAGE_KPAY = 'com.inicis.kpay';

  static const String PAYNOW = 'lguthepay-xpay';
  static const String PACKAGE_PAYNOW = 'com.lguplus.paynow';

  static const String WOORIWONCARD = 'com.wooricard.smartapp';
  static const String PACKAGE_WOORIWONCARD = 'com.wooricard.smartapp';

  static const String LPOINT = 'lmslpay';
  static const String PACKAGE_LPOINT = 'com.lottemembers.android';

  static const String WOORIWONBANK = 'wooribank';
  static const String PACKAGE_WOORIWONBANK = 'com.wooribank.smart.npib';

  static const String KTFAUTH = 'ktauthexternalcall';
  static const String PACKAGE_KTFAUTH = 'com.kt.ktauth';

  static const String LGTAUTH = 'upluscorporation';
  static const String PACKAGE_LGTAUTH = 'com.lguplus.smartotp';

  static const String SKTAUTH = 'tauthlink';
  static const String PACKAGE_SKTAUTH = 'com.sktelecom.tauth';

  static const String V3_MOBILE_PLUS = 'v3mobileplusweb';
  static const String PACKAGE_V3_MOBILE_PLUS = 'com.ahnlab.v3mobileplus';

  static const String KBBANK = 'kbbank';
  static const String PACKAGE_KBBANK = 'com.kbstar.kbkank';

  static const String LIIV_NEXT = 'newliiv';
  static const String PACKAGE_LIIV_NEXT = 'com.kbstar.reboot';
}
